/* Copyright (C) 2009, 2010, 2011 Keith Crane

This file is part DFILE Tools.

DFILE Tools is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at
your option) any later version.

DFILE Tools is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with DFILE Tools; see the file COPYING.  If not, see
<http://www.gnu.org/licenses/>. */


typedef struct {
	char	*value;
	size_t	length;
} field_t;

int alloc_record( field_t ***, size_t **, unsigned long );

void free_record( field_t **, unsigned long );

int append_tag( dfile_tag_t **, unsigned short *, dfile_tag_t *, unsigned short );

size_t sum_field_length( const dfile_bind_t *, unsigned short );

int alloc_record_key( field_t ***, size_t );

int format_hash_values( char ***, unsigned short );
